==> apexauthlib-0.1.0.tar.gz: apexauthlib-0.1.0/apexauthlib/integration/api.py <==
from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Generic, Mapping, TypeVar

from apexdevkit.formatter import Formatter
from apexdevkit.http import FluentHttp, JsonDict

ItemT = TypeVar("ItemT")


@dataclass(frozen=True)
class AuthApiProvider(Generic[ItemT]):
    http: FluentHttp
    service_name: str
    formatter: Formatter[Mapping[str, Any], ItemT]

    def login(self, username: str, password: str) -> str:
        data = {
            "grant_type": "password",
            "username": username,
            "password": password,
            "scope": "",
            "client_id": "string",
            "client_secret": "string",
        }

        return str(
            (
                self.http.with_data(JsonDict(data))
                .post()
                .on_endpoint("/auth/login")
                .on_failure(raises=RuntimeError)
                .json()
            )["access_token"]
        )

    def for_token(self, token: str) -> AuthApi[ItemT]:
        return AuthApi(self.http, self.service_name, self.formatter, token)


@dataclass(frozen=True)
class AuthApi(Generic[ItemT]):
    http: FluentHttp
    service_name: str
    formatter: Formatter[Mapping[str, Any], ItemT]
    token: str

    def user(self) -> str:
        return str(
            (
                self.http.with_header("Authorization", f"Bearer {self.token}")
                .get()
                .on_endpoint("/auth/user")
                .on_failure(raises=RuntimeError)
                .json()
            )["id"]
        )

    def metadata_for(self, user_id: str) -> ItemT:
        result = JsonDict(
            (
                self.http.with_header("Authorization", f"Bearer {self.token}")
                .get()
                .on_endpoint(f"/services/{self.service_name}/metadata/{user_id}")
                .on_failure(raises=RuntimeError)
                .json()
            )
        )

        return self.formatter.load(JsonDict(result["data"]["metadata"]["metadata"]))

==> apexauthlib-0.1.2.tar.gz: apexauthlib-0.1.2/apexauthlib/integration/api.py <==
from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Generic, Mapping, TypeVar

from apexdevkit.formatter import DataclassFormatter, Formatter
from apexdevkit.http import FluentHttp, JsonDict

from apexauthlib.entities import User

ItemT = TypeVar("ItemT")


@dataclass(frozen=True)
class AuthApiProvider(Generic[ItemT]):
    http: FluentHttp
    service_name: str
    formatter: Formatter[Mapping[str, Any], ItemT]

    def login(self, username: str, password: str) -> str:
        data = {
            "grant_type": "password",
            "username": username,
            "password": password,
            "scope": "",
            "client_id": "string",
            "client_secret": "string",
        }

        return str(
            (
                self.http.with_data(JsonDict(data))
                .post()
                .on_endpoint("/auth/login")
                .on_failure(raises=RuntimeError)
                .json()
            )["access_token"]
        )

    def for_token(self, token: str) -> AuthApi[ItemT]:
        return AuthApi(self.http, self.service_name, self.formatter, token)


@dataclass(frozen=True)
class AuthApi(Generic[ItemT]):
    http: FluentHttp
    service_name: str
    formatter: Formatter[Mapping[str, Any], ItemT]
    token: str

    def user(self) -> User:
        return DataclassFormatter(User).load(
            (
                self.http.with_header("Authorization", f"Bearer {self.token}")
                .get()
                .on_endpoint("/auth/user")
                .on_failure(raises=RuntimeError)
                .json()
            )
        )

    def metadata_for(self, user_id: str) -> ItemT:
        result = JsonDict(
            (
                self.http.with_header("Authorization", f"Bearer {self.token}")
                .get()
                .on_endpoint(f"/services/{self.service_name}/metadata/{user_id}")
                .on_failure(raises=RuntimeError)
                .json()
            )
        )

        return self.formatter.load(JsonDict(result["data"]["metadata"]["metadata"]))
